# Summary

- [Design Overview](./overview.md)
- [Tenets](./tenets.md)
- [Design FAQ](./faq.md)
- [Transport](transport/overview.md)
  - [HTTP Operations](transport/operation.md)
  - [HTTP Middleware](transport/middleware.md)

- [Smithy](./smithy/overview.md)
  - [Simple Shapes](./smithy/simple_shapes.md)
  - [Recursive Shapes](./smithy/recursive_shapes.md)
  - [Aggregate Shapes](./smithy/aggregate_shapes.md)
  - [Endpoint Resolution](smithy/endpoint.md)
  - [Backwards Compatibility](smithy/backwards-compat.md)

- [Server](./server/overview.md)
  - [Generating Common Service Code](./server/code_generation.md)
  - [Generating the Pokémon Service](./server/pokemon_service.md)
  - [Instrumentation](./server/instrumentation.md)
  <!-- - [The Anatomy of a Service](./server/anatomy.md) -->

- [RFCs](./rfcs/overview.md)
  - [RFC-0001: Sharing configuration between multiple clients](./rfcs/rfc0001_shared_config.md)
  - [RFC-0002: Supporting multiple HTTP versions for SDKs that use Event Stream](./rfcs/rfc0002_http_versions.md)
  - [RFC-0003: API for Pre-signed URLs](./rfcs/rfc0003_presigning_api.md)
  - [RFC-0004: Retry Behavior](./rfcs/rfc0004_retry_behavior.md)
  - [RFC-0005: Smithy Rust service framework](./rfcs/rfc0005_service_generation.md)
  - [RFC-0006: Service-specific middleware](./rfcs/rfc0006_service_specific_middleware.md)
  - [RFC-0007: Split release process](./rfcs/rfc0007_split_release_process.md)
  - [RFC-0008: Paginators](./rfcs/rfc0008_paginators.md)
  - [RFC-0009: Example Consolidation](./rfcs/rfc0009_example_consolidation.md)
  - [RFC-0010: Waiters](./rfcs/rfc0010_waiters.md)
  - [RFC-0011: Publishing Alpha to Crates.io](./rfcs/rfc0011_crates_io_alpha_publishing.md)
  - [RFC-0012: Independent Crate Versioning](./rfcs/rfc0012_independent_crate_versioning.md)
  - [RFC-0013: Body Callback APIs](./rfcs/rfc0013_body_callback_apis.md)
  - [RFC-0014: Fine-grained timeout configuration](./rfcs/rfc0014_timeout_config.md)
  - [RFC-0015: How Cargo "features" should be used in the SDK and runtime crates](./rfcs/rfc0015_using_features_responsibly.md)
  - [RFC-0016: Supporting Flexible Checksums](./rfcs/rfc0016_flexible_checksum_support.md)
  - [RFC-0017: Customizable Client Operations](./rfcs/rfc0017_customizable_client_operations.md)
  - [RFC-0018: Logging in the Presence of Sensitive Data](./rfcs/rfc0018_logging_sensitive.md)
  - [RFC-0019: Event Streams Errors](./rfcs/rfc0019_event_streams_errors.md)
  - [RFC-0020: Service Builder Improvements](./rfcs/rfc0020_service_builder.md)
  - [RFC-0021: Dependency Versions](./rfcs/rfc0021_dependency_versions.md)
  - [RFC-0022: Error Context and Compatibility](./rfcs/rfc0022_error_context_and_compatibility.md)
  - [RFC-0023: Evolving the new service builder API](./rfcs/rfc0023_refine_builder.md)

- [Contributing](./contributing/overview.md)
  - [Writing and debugging a low-level feature that relies on HTTP](./contributing/writing_and_debugging_a_low-level_feature_that_relies_on_HTTP.md)
